package org.example.lostpet5;

import java.io.File;
import java.io.IOException;
import java.util.ArrayList;
import java.util.List;

import android.app.Activity;
import android.app.AlertDialog;
import android.content.Context;
import android.content.DialogInterface;
import android.content.Intent;
import android.graphics.Color;
import android.graphics.Point;
import android.net.Uri;
import android.os.Bundle;
import android.provider.MediaStore;
import android.support.v4.app.Fragment;
import android.util.Log;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.widget.AdapterView;
import android.widget.BaseAdapter;
import android.widget.GridView;
import android.widget.ImageView;
import android.widget.Toast;
import android.widget.AdapterView.OnItemClickListener;
import android.widget.AdapterView.OnItemLongClickListener;

public class Camara extends Fragment{
	
	Activity actividad;
	GridView galeria;
	private ImageAdapter adapter;
	//Icono a mostrar
	private int tipo;
	//Posicion imagen camara
	private int posicion;
	//Posicion del elemento seleccionado
	private int posicionSel;
	//Path foto
	private String uri;	
	
	private long id;
	private List<String> imagenes;
	
	@Override
	public void onAttach(Activity actividad){
		super.onAttach(actividad);
		this.actividad=actividad;
		
		//Creamos Base Datos y obtenemos ultimo id
		BBDD bbdd=new BBDD(this.actividad.getApplicationContext());
        long last_id=bbdd.getLastID();
        this.id=last_id+1;        
	}
	
	public Camara(){
		//Tipo 0-Camara 1-Upload
        tipo=0;
        posicion=0;
        //Si es -1 no hay ninguno seleccionado
        posicionSel=-1;        
        imagenes=new ArrayList<String>();        
	}
	
	public View onCreateView(LayoutInflater inflater, ViewGroup container,Bundle savedInstanceState) {
		View rootView = inflater.inflate(R.layout.camara,container, false);
		galeria = (GridView) rootView.findViewById(R.id.galeria);
        adapter=new ImageAdapter(rootView.getContext());
        Point size=Utilidades.ObtenerTamanyoPantalla(actividad);
        int width=size.x/4-15;
        if(width<60)
        	width=60;
        galeria.setColumnWidth(width);
        galeria.setAdapter(adapter); 
        galeria.setOnItemClickListener(new OnItemClickListener() {
            public void onItemClick(AdapterView<?> parent, View v, int position, long id) {
            	//Se pulsa sobre icono camara
            	if(position==posicion && tipo==0){
            		hacerFoto();
            	}
            	//Se pulsa sobre el icono upload
            	else if(position==posicion && tipo==1){
            		obtenerGaleria();
            	}
            	//Se pulsa sobre imagen se hace zoom
            	else if(position<posicion){            		
            		Intent intent=new Intent(getActivity(),Zoom.class);
            		intent.putStringArrayListExtra("imagenes", (ArrayList<String>) imagenes); 
            		intent.putExtra("posicion", position);
            		startActivity(intent);
            	}
            }
        });    
        galeria.setOnItemLongClickListener(new OnItemLongClickListener(){
			@Override
			public boolean onItemLongClick(AdapterView<?> parent, View v, int position, long id) {
				//Se modifica el uso del icono de la camara
				if(position==posicion){
					tipo=(tipo==0)?1:0;
					adapter.notifyDataSetChanged();
				}
				//Se pulsa sobre imagen
				if(position<posicion){
					//Se obtine la posicion del seleccionado
					posicionSel=position;
					AlertDialog.Builder adb=new AlertDialog.Builder(actividad);
			        adb.setTitle(R.string.title_borrar);
			        adb.setMessage(R.string.msg_borrar);
			        adb.setNegativeButton(R.string.btn_no_borrar, null);
			        adb.setPositiveButton(R.string.btn_yes_borrar, new AlertDialog.OnClickListener() {
			            public void onClick(DialogInterface dialog, int which) {
			            	eliminarImagen();
			            }
			        });
			        adb.show();
				}
				//Prevenir se lanze onClick
				return true;
			}        	
        });        
        
        Toast toast = Toast.makeText(actividad.getApplicationContext(), actividad.getResources().getString(R.string.toastcamara), Toast.LENGTH_SHORT);
		toast.show();
        return rootView;
	}	
	
	public void onMyActivityResult(final int requestCode,final int resultCode, final Intent data) {
		if(resultCode!=Activity.RESULT_CANCELED){
    		switch(requestCode){
	    		case GLOBALES.SOLICITUD_HACER_FOTOGRAFIA:{
	    			guardarFoto();	    					    			
	    			break;
	    		}
	    		case GLOBALES.SELECCIONAR_IMAGEN:{
	    			if(data!=null){
	    				guardarGaleria(data.getData());			
	    			}
	    			break;
	    		}
	    	}
    	}
	}	
	
	public void hacerFoto(){
		try {
			File f=Ficheros.crearFicheroImagenTempExterno(this.id);
			uri=f.getAbsolutePath();
			Intent cameraIntent = new Intent(MediaStore.ACTION_IMAGE_CAPTURE);   
			cameraIntent.putExtra(MediaStore.EXTRA_OUTPUT, Uri.fromFile(f));
			//Lo lanza la actividad a causa del bug
			actividad.startActivityForResult(cameraIntent, GLOBALES.SOLICITUD_HACER_FOTOGRAFIA);	    	
		} catch (IOException e) {
			//Guardado a directorio interno
			uri=null;
			Log.e("Error",e.getMessage());			
		}		
	}	
	
	public void obtenerGaleria(){
    	Intent intent=new Intent(Intent.ACTION_PICK,MediaStore.Images.Media.EXTERNAL_CONTENT_URI);
		//Lo lanza la actividad a causa del bug
    	actividad.startActivityForResult(intent, GLOBALES.SELECCIONAR_IMAGEN);
	}
	
	public void guardarFoto(){
		//Uri es variable de clase porque por data no lo coje
		if(uri!=null){
			Ficheros.crearMiniatura(uri);
			imagenes.add(uri);
			posicion++;
			adapter.notifyDataSetChanged();
		}
	}
	
	public void guardarGaleria(Uri path){
		try {			
			String origen=Ficheros.obtenerRutaDesdeUri(path,actividad);
			if(origen!=null){
				File f = Ficheros.crearFicheroImagenTempExterno(this.id);
				Ficheros.copiarFichero(origen, f.getAbsolutePath());
				Ficheros.crearMiniatura(f.getAbsolutePath());
				imagenes.add(f.getAbsolutePath());
				posicion++;
				adapter.notifyDataSetChanged();		    				
			}
			else{				
				AlertDialog.Builder adb=new AlertDialog.Builder(actividad);
		        adb.setTitle(R.string.title_error_img);
		        adb.setMessage(R.string.msg_error_img);
		        adb.setNeutralButton(R.string.btn_yes_err_img, new AlertDialog.OnClickListener() {
		            public void onClick(DialogInterface dialog, int which) {
		            	dialog.cancel();
		            }
		        });
		        adb.show();
			}
		}catch(IOException e){							
			//Guardado a directorio interno
		}	    	
	}
	
	public void eliminarImagen(){
		String fichero=imagenes.get(posicionSel);
		Ficheros.eliminarImagen(fichero);
		//Elimino el fichero
		imagenes.remove(posicionSel);
		//Recargo el GridView
		adapter.notifyDataSetChanged();
		//Deselecciono
		posicionSel=-1;
		//Icono camara retocede
		posicion--;
	}
	
	public boolean esVacio(){
		return (imagenes.size()==0);
	}
	
	public long getID(){
		return this.id;
	}
	
	public List<String> getImagenes(){
		return this.imagenes;
	}
	
	private class ImageAdapter extends BaseAdapter {
        private Context mContext;

        public ImageAdapter(Context c) {
            mContext = c;
        }

        public int getCount() {
            return imagenes.size()+1;        	
        }

        public Object getItem(int position) {
            return null;
        }

        public long getItemId(int position) {
            return 0;
        }
        
        public View getView(int position, View convertView, ViewGroup parent) {
            ImageView imageView;
            if (convertView == null) {  
                imageView = new ImageView(mContext);    
                Point size=Utilidades.ObtenerTamanyoPantalla(actividad);
                int width=size.x/4-20;
                if(width<100)
                	width=100;
                int height=width+(width/4);
                imageView.setLayoutParams(new GridView.LayoutParams(width,height));                
                imageView.setScaleType(ImageView.ScaleType.FIT_CENTER);                               
            } else {
                imageView = (ImageView) convertView;
            }
            if(position==posicion && tipo==0 && posicion<12){
            	imageView.setBackgroundColor(Color.TRANSPARENT);
            	imageView.setImageResource(android.R.drawable.ic_menu_camera);            	
            }
            else if(position==posicion && tipo==1 && posicion<12){
            	imageView.setBackgroundColor(Color.TRANSPARENT);            	
            	imageView.setImageResource(android.R.drawable.ic_menu_upload);            	
            }
            else if(position<posicion){
            	imageView.setPadding(1, 1, 1, 1);
            	imageView.setBackgroundColor(Color.LTGRAY);
            	imageView.setImageURI(Uri.fromFile(new File(Ficheros.obtenerRutaMiniatura(imagenes.get(position)))));            	
            }
            return imageView;
        }              
          
    }		

}
