package org.example.lostpet5;

import java.io.File;
import java.io.FileInputStream;
import java.io.FileNotFoundException;
import java.io.FileOutputStream;
import java.io.IOException;
import java.io.InputStream;
import java.io.OutputStream;
import java.text.SimpleDateFormat;
import java.util.Date;
import java.util.Locale;

import android.app.Activity;
import android.database.Cursor;
import android.graphics.Bitmap;
import android.net.Uri;
import android.os.Environment;
import android.provider.MediaStore;
import android.util.Log;

/**
 * Clase estatica manejo archivos
@author Victor M Chisvert Amat 
@version 3
*/

public class Ficheros {
	
	/**
	 * Crea el fichero en el directorio externo
	 * @return File El fichero creado
	 * @throws IOException No se ha podido crear el fichero
	 */
	public static File crearFicheroImagenTempExterno(long id) throws IOException {
		// Create an image file name
		String timeStamp = new SimpleDateFormat("yyyyMMdd_HHmmss",Locale.GERMAN).format(new Date());
		String imageFileName = id+"_" + timeStamp;
		File albumF = obtenerDirTempExterno();
		if(albumF!=null){
			File imageF = File.createTempFile(imageFileName, GLOBALES.JPEG_FILE_SUFFIX, albumF);			
			return imageF;
		}
		throw new IOException("No existe el directorio");
	}
	
	/**
	 * Obtiene el Directorio temporal externo donde guardar las imagenes 	
	 * @return La ruta del directorio
	 */
	public static File obtenerDirTempExterno() {
		File storageDir = null;
		if (Environment.MEDIA_MOUNTED.equals(Environment.getExternalStorageState())) {
			storageDir = new File (Environment.getExternalStorageDirectory()+ GLOBALES.CAMERA_DIR + GLOBALES.TMP_NAME);
			if (storageDir != null) {
				if (! storageDir.mkdirs()) {
					if (! storageDir.exists()){
						Log.d("CameraSample", "failed to create directory");
						return null;
					}
				}
			}
			
		} else {
			Log.v("Error", "External storage is not mounted READ/WRITE.");
		}		
		return storageDir;
	}
	
	public static File crearFicheroImagenExterno(long id) throws IOException {
		// Create an image file name
		String timeStamp = new SimpleDateFormat("yyyyMMdd_HHmmss",Locale.GERMAN).format(new Date());
		String imageFileName = id+"_" + timeStamp;
		File albumF = obtenerDirExterno();
		if(albumF!=null){
			File imageF = File.createTempFile(imageFileName, GLOBALES.JPEG_FILE_SUFFIX, albumF);
			return imageF;
		}
		throw new IOException("No existe el directorio");
	}
	
	public static File obtenerDirExterno() {
		File storageDir = null;
		if (Environment.MEDIA_MOUNTED.equals(Environment.getExternalStorageState())) {
			storageDir = new File (Environment.getExternalStorageDirectory()+ GLOBALES.CAMERA_DIR + GLOBALES.DIR_NAME);
			if (storageDir != null) {
				if (! storageDir.mkdirs()) {
					if (! storageDir.exists()){
						Log.d("CameraSample", "failed to create directory");
						return null;
					}
				}
			}
			
		} else {
			Log.v("Error", "External storage is not mounted READ/WRITE.");
		}
		
		return storageDir;
	}
	
	public static void crearMiniatura(String f){
		Bitmap b=Utilidades.getBitmap(f, 100);
		FileOutputStream out;
		try {
			out = new FileOutputStream(obtenerRutaMiniatura(f));			
			b.compress(Bitmap.CompressFormat.JPEG, 75, out);
		} catch (FileNotFoundException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		}	    
	}
	
	public static String obtenerRutaMiniatura(String ruta){
		int pos=ruta.lastIndexOf("/");
		String path=ruta.substring(0, pos);
		String name=ruta.substring(pos+1, ruta.length());		
		return path+"/min_"+name;
	}
	
	/**
	 * Copia un fichero
	 * @param origen
	 * @param destino
	 * @return la ruta destino
	 * @throws IOException No se ha podido copiar
	 */
	public static String copiarFichero(String origen,String destino) throws IOException{
		InputStream in= new FileInputStream(origen);
		OutputStream out= new FileOutputStream(destino);
		byte[] buf = new byte[1024];
		int len;		 
		while ((len = in.read(buf)) > 0) {
		  out.write(buf, 0, len);
		}
		in.close();
		out.close();
		return destino;
	}
	
	public static String moverFichero(String origen,String destino) throws IOException{
		mover(obtenerRutaMiniatura(origen),obtenerRutaMiniatura(destino));
		return mover(origen,destino);
	}
	
	private static String mover(String origen, String destino) throws IOException{
		InputStream in= new FileInputStream(origen);
		OutputStream out= new FileOutputStream(destino);
		byte[] buf = new byte[1024];
		int len;		 
		while ((len = in.read(buf)) > 0) {
		  out.write(buf, 0, len);
		}
		in.close();
		out.close();
		new File(origen).delete();		
		return destino;
	}
	
	public static void eliminarImagen(String ruta){
		File f=new File(ruta);
		f.delete();
		File f_min=new File(obtenerRutaMiniatura(ruta));
		f_min.delete();
	}
	
	/**
	 * Borra todos los archivos temporales
	 */
	public static void BorrarImagenesTemp(){
		File f=obtenerDirTempExterno();
		if(f!=null){
			File files[]=f.listFiles();
			for(int i=0;i<files.length;i++){
				files[i].delete();
			}
		}
		else{
			//Borrar imagenes internas
		}
	}
	
	/**
	 * Borra un fichero
	 * @param fichero Ruta al fichero
	 */
	/*public static void BorrarFichero(String fichero){
		File f=new File(fichero);
		f.delete();
	}*/
	
	/**
	 * Pasado un uri devuelve la ruta 
	 * @param contentUri Uri a resolver
	 * @param activity actividad desde donde es llamado
	 * @return La ruta, o null si no ha podido resolverla
	 */
	public static String obtenerRutaDesdeUri(Uri contentUri,Activity activity) {
		try{
	        String[] proj = { MediaStore.Images.Media.DATA };
	        Cursor cursor = activity.getContentResolver().query(contentUri, proj, null, null, null);
	        int column_index = cursor.getColumnIndex(MediaStore.Images.Media.DATA);
	        cursor.moveToFirst();
	        return cursor.getString(column_index);
        }
		catch (NullPointerException e){}
        return null;
    }
}
