package org.example.lostpet5;

import com.google.android.gms.common.ConnectionResult;
import com.google.android.gms.common.GooglePlayServicesUtil;
import com.google.android.gms.maps.CameraUpdateFactory;
import com.google.android.gms.maps.GoogleMap;
import com.google.android.gms.maps.GoogleMap.OnMapLongClickListener;
import com.google.android.gms.maps.SupportMapFragment;
import com.google.android.gms.maps.model.LatLng;
import com.google.android.gms.maps.model.Marker;
import com.google.android.gms.maps.model.MarkerOptions;

import android.app.Activity;
import android.app.AlertDialog;
import android.app.Dialog;
import android.content.DialogInterface;
import android.content.Intent;
import android.location.Criteria;
import android.location.Location;
import android.location.LocationListener;
import android.location.LocationManager;
import android.os.Bundle;
import android.support.v4.app.FragmentActivity;
import android.view.Menu;
import android.view.MenuItem;
import android.widget.Toast;

public class Mapa extends FragmentActivity implements LocationListener, OnMapLongClickListener{
	
	 private Activity actividad;
	 private GoogleMap mapa;
	 private Location location;
	 private Marker marca;	 
	 private double lat,lng;
	 	 
	 @Override
	 protected void onCreate(Bundle savedInstanceState) {
		 super.onCreate(savedInstanceState);
		 setContentView(R.layout.mapa);
		 actividad=this;		 	
		 lat=getIntent().getDoubleExtra("lat",0);
		 lng=getIntent().getDoubleExtra("lng",0);
		 
		 int status = GooglePlayServicesUtil.isGooglePlayServicesAvailable(getBaseContext());
		 if(status!=ConnectionResult.SUCCESS){
			 int requestCode=10;
			 Dialog dialog=GooglePlayServicesUtil.getErrorDialog(status, this, requestCode);
			 dialog.show();
		 }
		 else{
			 mapa = ((SupportMapFragment) getSupportFragmentManager().findFragmentById(R.id.map)).getMap();
			 mapa.setMapType(GoogleMap.MAP_TYPE_NORMAL);		 
			 mapa.setMyLocationEnabled(true);
			 LocationManager lmanager=(LocationManager)getSystemService(LOCATION_SERVICE);
			 Criteria criteria=new Criteria();
			 String provider=lmanager.getBestProvider(criteria, true);
			 location=lmanager.getLastKnownLocation(provider);			 			 
			 if(location!=null){
				 mapa.setOnMapLongClickListener(this);
				 if(lat!=0 && lng!=0){
					LatLng position=new LatLng(lat,lng);
					marca=mapa.addMarker(new MarkerOptions().position(position));
					mapa.moveCamera(CameraUpdateFactory.newLatLng(position));
					mapa.animateCamera(CameraUpdateFactory.zoomTo(14));					
				 }
				 onLocationChanged(location);
			 }
			 mapa.getUiSettings().setZoomControlsEnabled(false);
			 mapa.getUiSettings().setCompassEnabled(true);
			 lmanager.requestLocationUpdates(provider,20000, 0, this);
			 Toast toast = Toast.makeText(this.getApplicationContext(), this.getResources().getString(R.string.toastmaps), Toast.LENGTH_SHORT);
			 toast.show();
		 }		 
	 }
	 
	@Override
	public boolean onCreateOptionsMenu(Menu menu) {
		getMenuInflater().inflate(R.menu.main2, menu);
		return super.onCreateOptionsMenu(menu);
	}
	
	@Override
	public boolean onOptionsItemSelected(MenuItem item) {
		switch (item.getItemId()) {	   		
	   		case R.id.volver:{
	   			returnParams();
	   			break;
	   		}
	   		case R.id.borrar_marca:{
	   			if(marca!=null){
	   				marca.remove();
	   				marca=null;
	   				onLocationChanged(location);
	   			}
	   			break;
	   		}
	   		case R.id.help2:{
	   			Toast toast = Toast.makeText(this.getApplicationContext(), this.getResources().getString(R.string.toastmaps), Toast.LENGTH_SHORT);
				 toast.show();
	   			break;
	   		}
		}
		return true;
	}
	
	protected void returnParams(){
		Intent intent=new Intent();
		intent.putExtra("resLat", this.lat);
		intent.putExtra("resLng", this.lng);
		this.setResult(GLOBALES.RESULTADO_MAPA,intent);
		finish();
	}
	
	@Override
	public void onBackPressed(){
		returnParams();		
	}
	 
	
	@Override
	public void onMapLongClick(LatLng latLng) {
		if(marca!=null){
			marca.remove();			
		}
		marca=mapa.addMarker(new MarkerOptions().position(latLng));	
		this.lat=latLng.latitude;
		this.lng=latLng.longitude;
	}


	@Override
	public void onLocationChanged(Location location) {
		double latitude=location.getLatitude();
		double longitude=location.getLongitude();
		LatLng latLng=new LatLng(latitude,longitude);
		if(marca==null){
			mapa.moveCamera(CameraUpdateFactory.newLatLng(latLng));
			mapa.animateCamera(CameraUpdateFactory.zoomTo(14));
		}		
	}


	@Override
	public void onProviderDisabled(String provider) {
		AlertDialog.Builder adb=new AlertDialog.Builder(actividad);
        adb.setTitle(R.string.title_gps);
        adb.setMessage(R.string.msg_gps);
        adb.setNegativeButton(R.string.btn_no_gps, null);
        adb.setPositiveButton(R.string.btn_yes_gps, new AlertDialog.OnClickListener() {
            public void onClick(DialogInterface dialog, int which) {
            	Intent intent=new Intent(android.provider.Settings.ACTION_LOCATION_SOURCE_SETTINGS);
    			startActivity(intent);
            }
        });
        adb.show();
	}


	@Override
	public void onProviderEnabled(String provider) {}


	@Override
	public void onStatusChanged(String provider, int status, Bundle extras) {}
	
}
